function data = deplot
% function data = deplot;
% Digitize data from a scanned image.
%
%  Keyboard commands when digitizing:
%     z = zoom in (centered on cursor)
%     u = unzoom (zoom out)
%     U = unzoom all the way
%     n = begin digitizing new curve
%     s = show current coordinates
%     q = quit digitizing
%
% Supported image formats include:  JPEG, TIFF, and BMP
%    (and any others supported by Matlab's imread() function).
%
% Christopher A. Shera (shera at mit.edu)
% Eaton-Peabody Laboratory
%  

% CAS modification
global DEPLOT;
load deplot

h0 = figure('Color',[0.8 0.8 0.8], ...
	'Colormap',mat0, ...
	'PaperPosition',[18 180 576 432], ...
	'PaperUnits','points', ...
	'Position',[507 329 615 582], ...
	'Tag','Deplotr', ...
        'Name','DEPLOT: Data Extraction Plus Lots O'' Tricks', ...
        'NumberTitle','off');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'ListboxTop',0, ...
	'Position',[14.6 1.230769230769231 38.40000000000001 4.384615384615385], ...
	'Style','frame', ...
	'Tag','Frame2');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'ListboxTop',0, ...
	'Position',[14.6 6.538461538461539 48.6 8], ...
	'Style','frame', ...
	'Tag','Frame1');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'ListboxTop',0, ...
	'Position',mat1, ...
	'String','Logarithmic x', ...
	'Style','checkbox', ...
	'Tag','XLogCheckbox');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'ListboxTop',0, ...
	'Position',mat2, ...
	'String','Logarithmic y', ...
	'Style','checkbox', ...
	'Tag','YLogCheckbox');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'ListboxTop',0, ...
	'Position',mat3, ...
	'String','Explicit origin', ...
	'Style','checkbox', ...
	'Tag','OriginCheckbox');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[1 1 1], ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',mat4, ...
	'String','0.0', ...
	'Style','edit', ...
	'Tag','XminEditText');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[1 1 1], ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',mat5, ...
	'String','1.0', ...
	'Style','edit', ...
	'Tag','XmaxEditText');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[1 1 1], ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',mat6, ...
	'String','0.0', ...
	'Style','edit', ...
	'Tag','YminEditText');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[1 1 1], ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',mat7, ...
	'String','1.0', ...
	'Style','edit', ...
	'Tag','YmaxEditText');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[16.8 12 6.2 1.230769230769231], ...
	'String','Min x', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[16.8 9.692307692307693 6.2 1.307692307692308], ...
	'String','Max x', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[40.8 12 6.2 1.230769230769231], ...
	'String','Min y', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[40.8 9.76923076923077 6.2 1.230769230769231], ...
	'String','Max y', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'Callback','deplot_callbacks digitize', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[69.60000000000001 8.205128205128204 24 3], ...
	'String','Digitize', ...
	'Tag','DigitizeButton');
h1 = axes('Parent',h0, ...
	'Units','characters', ...
	'CameraUpVector',[0 1 0], ...
	'CameraUpVectorMode','manual', ...
	'Color',[1 1 1], ...
	'ColorOrder',mat8, ...
	'FontName','Times', ...
	'FontSize',12, ...
	'LineWidth',1, ...
	'Position',[9.800000000000001 17.53846153846154 105.8 23.23076923076923], ...
	'Tag','Axes1', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'FontName','Times', ...
	'FontSize',12, ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[0.4981060606060607 -0.08637873754152814 9.160254037844386], ...
	'Tag','Axes1Text4', ...
	'VerticalAlignment','cap');
set(get(h2,'Parent'),'XLabel',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'FontName','Times', ...
	'FontSize',12, ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[-0.0625 0.4950166112956811 9.160254037844386], ...
	'Rotation',90, ...
	'Tag','Axes1Text3', ...
	'VerticalAlignment','baseline');
set(get(h2,'Parent'),'YLabel',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'FontName','Times', ...
	'FontSize',12, ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','right', ...
	'Position',[-0.0946969696969697 1.169435215946844 9.160254037844386], ...
	'Tag','Axes1Text2', ...
	'Visible','off');
set(get(h2,'Parent'),'ZLabel',h2);
h2 = text('Parent',h1, ...
	'Color',[0 0 0], ...
	'FontName','Times', ...
	'FontSize',12, ...
	'HandleVisibility','off', ...
	'HorizontalAlignment','center', ...
	'Position',[0.4981060606060607 1.026578073089701 9.160254037844386], ...
	'Tag','Axes1Text1', ...
	'VerticalAlignment','bottom');
set(get(h2,'Parent'),'Title',h2);
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'Callback','deplot_callbacks quit', ...
	'ListboxTop',0, ...
	'Position',mat9, ...
	'String','Quit dePlot', ...
	'Tag','QuitButton');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'Callback','deplot_callbacks load', ...
	'ListboxTop',0, ...
	'Position',mat10, ...
	'String','Load Scanned File', ...
	'Tag','LoadButton');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'ListboxTop',0, ...
	'Position',mat11, ...
	'String','Force perpendicular axes', ...
	'Style','checkbox', ...
	'Tag','PerpAxesCheckbox');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'ListboxTop',0, ...
	'Position',mat12, ...
	'String','Draw axes', ...
	'Style','checkbox', ...
	'Tag','DrawAxesCheckbox');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'Callback','deplot_callbacks help', ...
	'ListboxTop',0, ...
	'Position',[101 6.692307692307693 11.2 2.692307692307693], ...
	'String','Help', ...
	'Tag','HelpButton');
h1 = uicontrol('Parent',h0, ...
	'Units','characters', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'Callback','deplot_callbacks save', ...
	'Enable','off', ...
	'ListboxTop',0, ...
	'Position',[69.60000000000001 4.794871794871795 24 3], ...
	'String','Save Data', ...
	'Tag','SaveButton');

% CAS modification
DEPLOT.curve_id = 0;
DEPLOT.data = [];
DEPLOT.transform_defined = 0;
text(0.5,0.5,'dePlot', ...
     'FontSize',64, ...
     'HorizontalAlignment','center');
text(0.8,0.1,'by Dr. Callipygian', ...
     'FontSize',16, ...
     'HorizontalAlignment','center');
uiwait(h0);
data = DEPLOT.data;
